# -*- coding: utf-8 -*-
"""
w2lapp.login.py: bind with a specific bind DN and password

web2ldap - a web-based LDAP Client,
see http://www.web2ldap.de for details

(c) by Michael Stroeder <michael@stroeder.com>

This module is distributed under the terms of the
GPL (GNU GENERAL PUBLIC LICENSE) Version 2
(see http://www.gnu.org/copyleft/gpl.html)

$Id: login.py,v 1.48 2010/04/19 07:27:46 michael Exp $
"""

import w2lapp.core,w2lapp.gui,w2lapp.cnf

##############################################################################
# Login form
##############################################################################

def w2l_Login(
  sid,outf,command,form,ls,dn,scope,login_search_root,
  title_msg=u'Bind',
  login_msg='',
  who='',relogin=0,nomenu=0,
  login_default_mech=None
):
  """
  Provide a input form for doing a (re-)login
  """
  if 'login_who' in form.inputFieldNames:
    who = form.field['login_who'].value[0]

  login_search_root_field = w2lapp.gui.SearchRootField(form,ls,dn,name='login_search_root')
  login_search_root_field.setDefault(login_search_root)

  login_template_filename = w2lapp.gui.GetVariantFilename(
    w2lapp.cnf.GetParam(ls,'login_template',None),form.accept_language
  )

  if not login_template_filename:
    outf.write('<div id="ErrorMessage" class="Main"><p>No template file for login form specified.</p></div>')
    return

  try:
    # Read template from file
    login_template_str = open(login_template_filename,'r').read()
  except IOError:
    raise w2lapp.core.ErrorExit(u'I/O error during reading login form template file.')

  if nomenu:
    w2lapp.gui.PrintHeader(sid,outf,form,ls,login_msg)
    w2lapp.gui.StatusLine(sid,outf,form,ls,dn)
  else:
    w2lapp.gui.TopSection(
      sid,outf,form,ls,dn,
      login_msg,
      w2lapp.gui.MainMenu(sid,form,ls,dn),
      context_menu_list=[]
    )

  if ls.rootDSE:
    form.field['login_mech'].setOptions(ls.rootDSE.get('supportedSASLMechanisms',None))

  # Determine the bind mech to be used from the form data or the key-word argument login_default_mech
  login_mech = form.getInputValue('login_mech',[w2lapp.cnf.GetParam(ls,'login_default_mech','')])[0] or login_default_mech or ''

  login_fields = login_template_str % (
    form.field['login_mech'].inputHTML(default=login_mech),
    form.utf2display(who),
    form.utf2display(unicode(w2lapp.cnf.GetParam(ls,'binddnsearch',r'(uid=%s)'))),
    login_search_root_field.inputHTML(),
    {0:'Login',1:'Retry w/login'}[relogin],
  )

  scope_str = form.getInputValue('scope',[scope])[0]
  if scope_str is None:
    scope_hidden_field = ''
  else:
    scope_hidden_field = w2lapp.gui.HIDDEN_FIELD % ('scope',scope_str,'')

  outf.write("""
<div id="ErrorMessage" class="Main">
  <h1>%s</h1>
  <p>%s</p>
  %s\n%s\n%s\n%s\n%s
"""  % (
      form.utf2display(title_msg),
      login_msg or '&nbsp;',
      form.beginFormHTML(command,sid,'POST',None),
      w2lapp.gui.HIDDEN_FIELD % ('ldapurl',ls.uri.encode('ascii'),''),
      w2lapp.gui.HIDDEN_FIELD % ('dn',form.utf2display(dn,sp_entity='  '),''),
      scope_hidden_field.encode('ascii'),
      login_fields,
    )
  )
  if relogin:
    form.hiddenInputFields(
      outf,
      [
        'sid','ldapurl','host','who','cred','dn','scope',
        'login_mech','login_authzid','login_realm',
        'login_search_root','login_filterstr'
      ]
    )
  outf.write('</form>\n</div>\n')
  w2lapp.gui.PrintFooter(outf,form)

